@@ -138,7 +138,9 @@ def make_consumer(request):
 def render_openid_request(request, openid_request, return_to, immediate=False, trust_root=None):
     """Render an OpenID authentication request."""
     if trust_root is None:
-        trust_root = request.build_absolute_uri('/')
+        trust_root = getattr(
+            settings, 'OPENID_CUSTOM_REALM', request.build_absolute_uri('/')
+        )
 
     if openid_request.shouldSendRedirect():
         redirect_url = openid_request.redirectURL(trust_root, return_to, immediate)
